@@ -1,13 +1,13 @@
 //@ts-check
 
-import "/gridchen/webcomponent.js"
-import { createView } from "/gridchen/matrixview.js";
+import "gridchen/webcomponent.js"
+import { createView } from "gridchen/matrixview.js";
 import {
     NumberConverter,
     DateTimeStringConverter,
     DatePartialTimeStringConverter,
     StringConverter
-} from "/gridchen/converter.js";
+} from "gridchen/converter.js";
 
 /**
  * Example:
@@ -690,11 +690,14 @@ export function createFormChen(topSchema, topObj, transactionManager) {
         };
 
         label.textContent = node.title;
-
-        if (schema.description) {
-            label.title = schema.description;
+        if (node.parent && node.parent.parent !== undefined) {
+            label.textContent = node.parent.title + ' ' + node.title;
         }
 
+        //if (schema.description) {
+        //    label.title = schema.description;
+        //}
+
         if (schema.unit) {
             const unit = document.createElement('span');
             unit.className += ' unit';
